@@ -36,22 +36,29 @@ sub end : Private {
 	$c->error( 0 );
 }
 
-__PACKAGE__->config->{authentication}{users} = {
-	foo => {
-		password => "bar",
-		os => "windows",
-	},
-	gorch => {
-		password => "moose",
-		roles => [qw/child/],
-		os => "linux",
-	},
-	quxx => {
-		password => "ding",
-		roles => [qw/moose_trainer/],
-		os => "osx",
-	}
-};
+__PACKAGE__->config(
+    authentication => {
+        users => {
+            foo => {
+                password => "bar",
+                os => "windows",
+            },
+            gorch => {
+                password => "moose",
+                roles => [qw/child/],
+                os => "linux",
+            },
+            quxx => {
+                password => "ding",
+                roles => [qw/moose_trainer/],
+                os => "osx",
+            },
+        },
+    },
+    acl => {
+        deny => ["/restricted"],
+    }
+);
 
 __PACKAGE__->setup;
 
@@ -59,7 +66,8 @@ __PACKAGE__->allow_access_if("/", sub { 1 }); # just to test that / can be appli
 
 __PACKAGE__->deny_access_unless("/lioncage", [qw/zoo_worker lion_tamer/]); # only highly trained personnel can enter
 
-__PACKAGE__->deny_access_unless("/restricted", sub { 0 }); # no one can access
+# this now in config
+# __PACKAGE__->deny_access_unless("/restricted", sub { 0 }); # no one can access
 
 __PACKAGE__->deny_access_unless("/zoo", sub {
 	my ( $c, $action ) = @_;
